==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Polyline/DrawPolyline/ts/DrawPolyline_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>DrawPolyline</name>
    <message>
        <location filename="../DrawPolyline.js" line="+69"/>
        <source>First vertex</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pierwszy wierzchołek</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Next vertex</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Następny wierzchołek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation type="unfinished">Zrobione</translation>
    </message>
    <message>
        <location line="+418"/>
        <source>close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>arc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../DrawPolyline.ui" line="+23"/>
        <source>Close polyline</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zamknij polilinia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>,, C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Undo Previous Segment</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Cofnąć poprzedni segment</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Redo Segment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Arc with radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>,, A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Sweep</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Restrict length or angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arc segment with radius:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Odcinka łuku o promieniu:</translation>
    </message>
    <message>
        <location filename="../DrawPolylineInit.js" line="+2"/>
        <source>&amp;Draw Polyline</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narysuj łamaną</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw polyline with line and arc segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narysuj polilinię z segmentów linii i łuku</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Polyline/DrawPolyline/ts/DrawPolyline_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>DrawPolyline</name>
    <message>
        <location filename="../DrawPolyline.js" line="+70"/>
        <source>First vertex</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Pierwszy wierzchołek</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Next vertex</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Następny wierzchołek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation>Zrobione</translation>
    </message>
    <message>
        <location line="+418"/>
        <source>close</source>
        <translation>zamknij</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>undo</source>
        <translation>cofnij</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>redo</source>
        <translation>ponów</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>arc</source>
        <translation>łuk</translation>
    </message>
    <message>
        <location filename="../DrawPolyline.ui" line="+23"/>
        <source>Close polyline</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zamknij linię łamaną</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>,, C</source>
        <translation>,, C</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Undo Previous Segment</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cofnij poprzedni segment</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, U</source>
        <translation>,, U</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Redo Segment</source>
        <translation>Ponów segment</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, R</source>
        <translation>,, R</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Arc with radius:</source>
        <translation>Łuk z promieniem:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>,, A</source>
        <translation>,A</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Sweep</source>
        <translation>Rozwarcie</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Restrict length or angle</source>
        <translation>Ogranicz długość lub kąt</translation>
    </message>
    <message>
        <source>Arc segment with radius:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Odcinka łuku o promieniu:</translation>
    </message>
    <message>
        <location filename="../DrawPolylineInit.js" line="+2"/>
        <source>&amp;Draw Polyline</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ł&amp;amana</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw polyline with line and arc segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje linię łamaną z segmentów liniowych i łukowych</translation>
    </message>
</context>
</TS>
